@@ -3,7 +3,7 @@ BEGIN {
   $Moose::Meta::Attribute::Native::Trait::Bool::AUTHORITY = 'cpan:STEVAN';
 }
 BEGIN {
-  $Moose::Meta::Attribute::Native::Trait::Bool::VERSION = '2.0002';
+  $Moose::Meta::Attribute::Native::Trait::Bool::VERSION = '2.0003';
 }
 use Moose::Role;
 
@@ -16,8 +16,20 @@ no Moose::Role;
 
 1;
 
+# ABSTRACT: Helper trait for Bool attributes
+
+
+
 =pod
 
+=head1 NAME
+
+Moose::Meta::Attribute::Native::Trait::Bool - Helper trait for Bool attributes
+
+=head1 VERSION
+
+version 2.0003
+
 =head1 SYNOPSIS
 
   package Room;
@@ -82,4 +94,19 @@ Equivalent of 'not C<$value>'.
 
 See L<Moose/BUGS> for details on reporting bugs.
 
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
