@@ -3,7 +3,7 @@ BEGIN {
   $Moose::Meta::Attribute::Native::Trait::Code::AUTHORITY = 'cpan:STEVAN';
 }
 BEGIN {
-  $Moose::Meta::Attribute::Native::Trait::Code::VERSION = '2.0002';
+  $Moose::Meta::Attribute::Native::Trait::Code::VERSION = '2.0003';
 }
 use Moose::Role;
 
@@ -15,8 +15,20 @@ no Moose::Role;
 
 1;
 
+# ABSTRACT: Helper trait for CodeRef attributes
+
+
+
 =pod
 
+=head1 NAME
+
+Moose::Meta::Attribute::Native::Trait::Code - Helper trait for CodeRef attributes
+
+=head1 VERSION
+
+version 2.0003
+
 =head1 SYNOPSIS
 
   package Foo;
@@ -64,4 +76,19 @@ Calls the coderef with the the instance as invocant and given args.
 
 See L<Moose/BUGS> for details on reporting bugs.
 
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
