@@ -3,7 +3,7 @@ BEGIN {
   $Moose::Meta::Role::Application::ToInstance::AUTHORITY = 'cpan:STEVAN';
 }
 BEGIN {
-  $Moose::Meta::Role::Application::ToInstance::VERSION = '2.0002';
+  $Moose::Meta::Role::Application::ToInstance::VERSION = '2.0003';
 }
 
 use strict;
@@ -11,6 +11,7 @@ use warnings;
 use metaclass;
 
 use Scalar::Util 'blessed';
+use List::MoreUtils 'all';
 
 use base 'Moose::Meta::Role::Application';
 
@@ -33,7 +34,7 @@ sub apply {
     my $class = $obj_meta->create_anon_class(
         superclasses => [ blessed($object) ],
         roles => [ $role, keys(%$args) ? ($args) : () ],
-        cache => 1,
+        cache => (all { $_ eq '-alias' || $_ eq '-excludes' } keys %$args),
     );
 
     $class->rebless_instance( $object, %{ $self->rebless_params } );
@@ -53,7 +54,7 @@ Moose::Meta::Role::Application::ToInstance - Compose a role into an instance
 
 =head1 VERSION
 
-version 2.0002
+version 2.0003
 
 =head1 DESCRIPTION
 
