@@ -3,7 +3,7 @@ BEGIN {
   $Moose::Meta::Role::Attribute::AUTHORITY = 'cpan:STEVAN';
 }
 BEGIN {
-  $Moose::Meta::Role::Attribute::VERSION = '2.0002';
+  $Moose::Meta::Role::Attribute::VERSION = '2.0003';
 }
 
 use strict;
@@ -122,8 +122,20 @@ sub is_same_as {
 
 1;
 
+# ABSTRACT: The Moose attribute metaclass for Roles
+
+
+
 =pod
 
+=head1 NAME
+
+Moose::Meta::Role::Attribute - The Moose attribute metaclass for Roles
+
+=head1 VERSION
+
+version 2.0003
+
 =head1 DESCRIPTION
 
 This class implements the API for attributes in roles. Attributes in roles are
@@ -189,4 +201,19 @@ L<Moose::Meta::Attribute> (and L<Class::MOP::Attribute>).
 
 See L<Moose/BUGS> for details on reporting bugs.
 
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
