@@ -4,7 +4,7 @@ BEGIN {
   $Moose::Object::AUTHORITY = 'cpan:STEVAN';
 }
 BEGIN {
-  $Moose::Object::VERSION = '2.0002';
+  $Moose::Object::VERSION = '2.0003';
 }
 
 use strict;
@@ -146,7 +146,7 @@ Moose::Object - The base object for Moose
 
 =head1 VERSION
 
-version 2.0002
+version 2.0003
 
 =head1 DESCRIPTION
 
@@ -154,8 +154,9 @@ This class is the default base class for all Moose-using classes. When
 you C<use Moose> in this class, your class will inherit from this
 class.
 
-It provides a default constructor and destructor, which run the
-C<BUILDALL> and C<DEMOLISHALL> methods respectively.
+It provides a default constructor and destructor, which run all of the
+C<BUILD> and C<DEMOLISH> methods in the inheritance hierarchy,
+respectively.
 
 You don't actually I<need> to inherit from this in order to use Moose,
 but it makes it easier to take advantage of all of Moose's features.
@@ -164,13 +165,14 @@ but it makes it easier to take advantage of all of Moose's features.
 
 =over 4
 
-=item B<< Moose::Object->new(%params) >>
+=item B<< Moose::Object->new(%params|$params) >>
 
 This method calls C<< $class->BUILDARGS(@_) >>, and then creates a new
 instance of the appropriate class. Once the instance is created, it
-calls C<< $instance->BUILDALL($params) >>.
+calls C<< $instance->BUILD($params) >> for each C<BUILD> method in the
+inheritance hierarchy.
 
-=item B<< Moose::Object->BUILDARGS(%params) >>
+=item B<< Moose::Object->BUILDARGS(%params|$params) >>
 
 The default implementation of this method accepts a hash or hash
 reference of named parameters. If it receives a single argument that
@@ -181,27 +183,11 @@ options passed to the constructor.
 
 This method should always return a hash reference of named options.
 
-=item B<< $object->BUILDALL($params) >>
-
-This method will call every C<BUILD> method in the inheritance
-hierarchy, starting with the most distant parent class and ending with
-the object's class.
-
-The C<BUILD> method will be passed the hash reference returned by
-C<BUILDARGS>.
-
-=item B<< $object->DEMOLISHALL >>
-
-This will call every C<DEMOLISH> method in the inheritance hierarchy,
-starting with the object's class and ending with the most distant
-parent. C<DEMOLISHALL> and C<DEMOLISH> will receive a boolean
-indicating whether or not we are currently in global destruction.
-
 =item B<< $object->does($role_name) >>
 
 This returns true if the object does the given role.
 
-=item B<DOES ($class_or_role_name)>
+=item B<< $object->DOES($class_or_role_name) >>
 
 This is a a Moose role-aware implementation of L<UNIVERSAL/DOES>.
 
@@ -217,6 +203,12 @@ C<UNIVERSAL::DOES>.
 This is a handy utility for C<Data::Dumper>ing an object. By default,
 the maximum depth is 1, to avoid making a mess.
 
+=item B<< $object->DESTROY >>
+
+A default destructor is provided, which calls
+C<< $instance->DEMOLISH($in_global_destruction) >> for each C<DEMOLISH>
+method in the inheritance hierarchy.
+
 =back
 
 =head1 BUGS
